/**
 * The {@code Struct} package is a versatile collection of data structures designed for
 * competitive programming. It includes advanced structures that are highly optimized
 * to tackle complex problems, as well as classes meant for conveniently managing data.
 *
 * <p> Included Data Structures:
 * <ul>
 *   <li>{@link Struct.BSTNode} - Represents a node in a Binary Search Tree (BST).</li>
 *   <li>{@link Struct.DSU} - Implements a Disjoint Set Union (also known as Union-Find),
 *       useful for keeping track of a partition of a set into disjoint subsets.</li>
 *   <li>{@link Struct.ListNode} - Defines a node for a doubly linked list, commonly used
 *       in various list operations.</li>
 *   <li>{@link Struct.SegTree} - Implements a Segment Tree, a data structure
 *       for efficient query and update operations on array intervals.</li>
 *   <li>{@link Struct.Trie} - Implements a Trie (or prefix tree), which is an ordered tree
 *       data structure used for efficient String lookup</li>
 *   <li>{@link Struct.Single} - Encapsulates a single value within an object, sometimes
 *       useful for passing mutable values to methods or storing in collections.</li>
 *   <li>{@link Struct.Pair} - Generic class for a tuple of two items, often used to store
 *       two related objects together without creating a specific class.</li>
 *   <li>{@link Struct.Triple} - Generalizes Pair to include three related elements,
 *    allowing the association of three objects.</li>
 *   <li>{@link Struct.Quad} - Extends the concept of Pair to include four related elements,
 *       useful for complex state or result capturing.</li>
 * </ul>
 *
 * <p> Use these data structures to increase the efficiency and readability of your competitive
 * programming solutions.
 *
 * @author Sahasrad Chippa
 * @version 1.0
 * @since 1.0
 */
package Struct;