/**
 * The {@code Util} package offers specialized classes for algorithmic operations
 * data manipulation, mathematical computations, and standardized input/output handling.
 * The design of these tools focuses on efficiency, simplicity, and flexibility for
 * competitive programmers/
 *
 * <p>Classes included in this package:
 * <ul>
 *   <li>{@link Util.Algo} - Provides static methods for efficient algorithmic operations such as binary
 *       and ternary searches, supporting operations with generic data types.</li>
 *   <li>{@link Util.Calc} - Offers a series of static methods for complex mathematical computations
 *       including modular inverses, exponentiation, and more.</li>
 *   <li>{@link Util.Constants} - Centralizes commonly used constants and configurations needed in
 *       competitive programming, such as modulo values and debug flags.</li>
 *   <li>{@link Util.Data} - Delivers utility methods for data manipulation, like finding min/max values,
 *       and calculating prefix and suffix sums across various data types.</li>
 *   <li>{@link Util.In} - Facilitates input operations from different sources ({@link java.lang.System#in} by default)
 *       with support for parsing primitive types and strings, as well as custom tokenization.</li>
 *   <li>{@link Util.Out} - Handles output operations efficiently with capabilities for stream redirection,
 *       custom delimiters, and deferred flushing to maintain runtime performance.</li>
 * </ul>
 *
 * <p>This package is structured to provide productivity boosts in competitive programming
 * by reducing boilerplate code and enhancing the performance of common computational and I/O tasks.
 * @author Sahasrad Chippa
 * @version 1.0
 * @since 1.0
 */
package Util;